# import mistletoe
# from mistletoe.latex_renderer import LaTeXRenderer
#
# with open(r"C:\Users\jxgm\Desktop\FileTranslate\tests\resource\互联网认证授权机制.md","r",encoding="utf-8") as f:
#     md=f.read()
# html = mistletoe.markdown(md)
# # with open(r"./output.html","w",encoding="utf-8") as f:
# #     f.write(html)
# from fpdf import FPDF
# pdf = FPDF()
# pdf.add_page()
# pdf.write_html(html)
# pdf.output("pdf-from-markdown-with-mistletoe.pdf")